@@ -10,8 +10,6 @@ function(
   assignments=file.choose(new=FALSE)
 ){
 
-  obs <- data[,2]
-
   if(design=="CRD"){
     if(save=="yes"){
       file<-file.choose(new=FALSE)
@@ -44,38 +42,46 @@ function(
     for(it in 1:number){
       mean.b[it]<-mean(bscores[it,])
     }
+    distribution<-numeric(number)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(number)
       for(it in 1:number){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(number)
+    else if(statistic=="B-A"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(number)
+    else if(statistic=="|A-B|"){
       for(it in 1:number){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:number){
+        A<-ascores[it,]
+        B<-bscores[it,]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/number
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE)
     }
-    return(p.value)
     unlink(file.a,recursive=FALSE)
     unlink(file.b,recursive=FALSE)
+    return(p.value)
   }
   
   if(design=="RBD"){
@@ -116,38 +122,46 @@ function(
     for(it in 1:number){
       mean.b[it]<-mean(bscores[it,])
     }
+    distribution<-numeric(number)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(number)
       for(it in 1:number){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(number)
+    else if(statistic=="B-A"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(number)
+    else if(statistic=="|A-B|"){
       for(it in 1:number){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:number){
+        A<-ascores[it,]
+        B<-bscores[it,]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/number
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE)
     }
-    return(p.value)
     unlink(file.a,recursive=FALSE)
     unlink(file.b,recursive=FALSE)
+    return(p.value)
   }
   
   if(design=="ATD"){
@@ -203,38 +217,46 @@ function(
     for(it in 1:number){
       mean.b[it]<-mean(bscores[it,])
     }
+    distribution<-numeric(number)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(number)
       for(it in 1:number){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(number)
+    else if(statistic=="B-A"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(number)
+    else if(statistic=="|A-B|"){
       for(it in 1:number){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:number){
+        A<-ascores[it,]
+        B<-bscores[it,]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/number
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE)
     }
-    return(p.value)
     unlink(file.a,recursive=FALSE)
     unlink(file.b,recursive=FALSE)
+    return(p.value)
   }
   
   if(design=="AB"){
@@ -256,39 +278,44 @@ function(
     for(it in 1:number){
       scores.b[[it]]<-c(observed[(1+index.a[selection[it]]):length(observed)])
     }
+    distribution<-numeric(number)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(number)
       for(it in 1:number){
         distribution[it]<-mean(scores.a[[it]])-mean(scores.b[[it]])
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(number)
+    else if(statistic=="B-A"){
       for(it in 1:number){
         distribution[it]<-mean(scores.b[[it]])-mean(scores.a[[it]])
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(number)
+    else if(statistic=="|A-B|"){
       for(it in 1:number){
         distribution[it]<-abs(mean(scores.a[[it]])-mean(scores.b[[it]]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:number){
+        A<-scores.a[[it]]
+        B<-scores.b[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/number
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-    }
-    if(save=="no"){
-      return(p.value)
     }
+    return(p.value)
   }
   
   if(design=="ABA"){
@@ -351,87 +378,86 @@ function(
     for(it in 1:number){
       mean.a2[it]<-mean(scores.a2[[it]])
     }
+    distribution<-numeric(number)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(number)
       for(it in 1:number){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b1)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(number)
+    else if(statistic=="B-A"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b1)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(number)
+    else if(statistic=="|A-B|"){
       for(it in 1:number){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b1))
     }
-    if(statistic=="PA-PB"){
-      distribution<-numeric(number)
+    else if(statistic=="PA-PB"){
       for(it in 1:number){
         distribution[it]<-pmean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-((mean(observed.a1)+mean(observed.a2))/2)-mean(observed.b1)
     }
-    if(statistic=="PB-PA"){
-      distribution<-numeric(number)
+    else if(statistic=="PB-PA"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-pmean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b1)-((mean(observed.a1)+mean(observed.a2))/2)
     }
-    if(statistic=="|PA-PB|"){
-      distribution<-numeric(number)
+    else if(statistic=="|PA-PB|"){
       for(it in 1:number){
         distribution[it]<-abs(pmean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(((mean(observed.a1)+mean(observed.a2))/2)-mean(observed.b1))
     }
-    if(statistic=="AA-BB"){
-      distribution<-numeric(number)
+    else if(statistic=="AA-BB"){
       for(it in 1:number){
         distribution[it]<-(mean.a1[it]+mean.a2[it])-(mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.a1)+mean(observed.a2))-(mean(observed.b1))
     }
-    if(statistic=="BB-AA"){
-      distribution<-numeric(number)
+    else if(statistic=="BB-AA"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-(mean.a1[it]+mean.a2[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.b1))-(mean(observed.a1)+mean(observed.a2))
     }
-    if(statistic=="|AA-BB|"){
-      distribution<-numeric(number)
+    else if(statistic=="|AA-BB|"){
       for(it in 1:number){
         distribution[it]<-abs((mean.a1[it]+mean.a2[it])-(mean.b[it]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs((mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)))
     }
+    else{
+      for(it in 1:number){
+        A1<-scores.a1[[it]]
+        B1<-scores.b1[[it]]
+        A2<-scores.a2[[it]]
+        A<-scores.a[[it]]
+        B<-scores.b1[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A1<-observed.a1
+      B1<-observed.b1	
+      A2<-observed.a2
+      A<-observed.a
+      B<-observed.b1
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/number
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-    }
-    if(save=="no"){
-      return(p.value)
     }
+    return(p.value)
   }
   
   if(design=="ABAB"){
@@ -524,87 +550,88 @@ function(
     for(it in 1:number){
       mean.b2[it]<-mean(scores.b2[[it]])
     }
+    distribution<-numeric(number)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(number)
       for(it in 1:number){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(number)
+    else if(statistic=="B-A"){
       for(it in 1:number){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(number)
+    else if(statistic=="|A-B|"){
       for(it in 1:number){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
-    if(statistic=="PA-PB"){
-      distribution<-numeric(number)
+    else if(statistic=="PA-PB"){
       for(it in 1:number){
         distribution[it]<-pmean.a[it]-pmean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-((mean(observed.a1)+mean(observed.a2))/2)-((mean(observed.b1)+mean(observed.b2))/2)
     }
-    if(statistic=="PB-PA"){
-      distribution<-numeric(number)
+    else if(statistic=="PB-PA"){
       for(it in 1:number){
         distribution[it]<-pmean.b[it]-pmean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-((mean(observed.b1)+mean(observed.b2))/2)-((mean(observed.a1)+mean(observed.a2))/2)
     }
-    if(statistic=="|PA-PB|"){
-      distribution<-numeric(number)
+    else if(statistic=="|PA-PB|"){
       for(it in 1:number){
         distribution[it]<-abs(pmean.a[it]-pmean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(((mean(observed.a1)+mean(observed.a2))/2)-((mean(observed.b1)+mean(observed.b2))/2))
     }
-    if(statistic=="AA-BB"){
-      distribution<-numeric(number)
+    else if(statistic=="AA-BB"){
       for(it in 1:number){
         distribution[it]<-(mean.a1[it]+mean.a2[it])-(mean.b1[it]+mean.b2[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)+mean(observed.b2))
     }
-    if(statistic=="BB-AA"){
-      distribution<-numeric(number)
+    else if(statistic=="BB-AA"){
       for(it in 1:number){
         distribution[it]<-(mean.b1[it]+mean.b2[it])-(mean.a1[it]+mean.a2[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.b1)+mean(observed.b2))-(mean(observed.a1)+mean(observed.a2))
     }
-    if(statistic=="|AA-BB|"){
-      distribution<-numeric(number)
+    else if(statistic=="|AA-BB|"){
       for(it in 1:number){
         distribution[it]<-abs((mean.a1[it]+mean.a2[it])-(mean.b1[it]+mean.b2[it]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs((mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)+mean(observed.b2)))
     }
+    else{
+      for(it in 1:number){
+        A1<-scores.a1[[it]]
+        B1<-scores.b1[[it]]
+        A2<-scores.a2[[it]]
+        B2<-scores.b2[[it]]
+        A<-scores.a[[it]]
+        B<-scores.b[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A1<-observed.a1
+      B1<-observed.b1	
+      A2<-observed.a2
+      B2<-observed.b2
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/number
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-    }
-    if(save=="no"){
-      return(p.value)
     }
+    return(p.value)
   }
   
   if(design=="MBD"){
@@ -647,24 +674,31 @@ function(
     for(it in 1:N){
       observed.b[[it]]<-data[,it*2][data[,(it*2)-1]=="B"]
     }
+    differences<-numeric(N)
+    
     if(statistic=="A-B"){
-      differences<-numeric(N)
       for(it in 1:N){
         differences[it]<-mean(observed.a[[it]])-mean(observed.b[[it]])
       }
     }
-    if(statistic=="B-A"){
-      differences<-numeric(N)
+    else if(statistic=="B-A"){
       for(it in 1:N){
         differences[it]<-mean(observed.b[[it]])-mean(observed.a[[it]])
       }
     }
-    if(statistic=="|A-B|"){
-      differences<-numeric(N)
+    else if(statistic=="|A-B|"){
       for(it in 1:N){
         differences[it]<-abs(mean(observed.b[[it]])-mean(observed.a[[it]]))
       }
     }
+    else{
+      for(it in 1:N){
+        A<-observed.a[[it]]
+        B<-observed.b[[it]]
+        differences[it]<-eval(parse(text=statistic))
+      }
+    }
+    
     observed.statistic<-mean(differences)
     scores.a<-list()
     for(iter in 1:number){
@@ -682,8 +716,9 @@ function(
       }
       scores.b[[iter]]<-bscores
     }
+    differs<-list()
+    
     if(statistic=="A-B"){
-      differs<-list()
       for(iter in 1:number){
         differ<-numeric(N)
         for(it in 1:N){
@@ -692,8 +727,7 @@ function(
         differs[[iter]]<-differ
       }
     }
-    if(statistic=="B-A"){
-      differs<-list()
+    else if(statistic=="B-A"){
       for(iter in 1:number){
         differ<-numeric(N)
         for(it in 1:N){
@@ -702,8 +736,7 @@ function(
         differs[[iter]]<-differ
       }
     }
-    if(statistic=="|A-B|"){
-      differs<-list()
+    else if(statistic=="|A-B|"){
       for(iter in 1:number){
         differ<-numeric(N)
         for(it in 1:N){
@@ -712,6 +745,18 @@ function(
         differs[[iter]]<-differ
       }
     }
+    else{
+      for(iter in 1:number){
+        differ<-numeric(N)
+        for(it in 1:N){
+          A<-scores.a[[iter]][[it]]
+          B<-scores.b[[iter]][[it]]
+          differ[it]<-eval(parse(text=statistic))
+        }
+        differs[[iter]]<-differ
+      }
+    }
+    
     distribution<-numeric(number)
     for(it in 1:number){
       distribution[it]<-mean(differs[[it]])
@@ -724,19 +769,12 @@ function(
     }
     if(save=="yes"|save=="check"){
       write.table(distribution,file=fileSAVE,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-      unlink(fileCOMBSTARTPTS,recursive=FALSE)
-    }
-    if(save=="no"){
-      return(p.value)
-      unlink(fileCOMBSTARTPTS,recursive=FALSE)
     }
+    unlink(fileCOMBSTARTPTS,recursive=FALSE)
+    return(p.value)
   }
   
   if(design=="Custom"){
-    if(!(statistic=="A-B"||statistic=="B-A"||statistic=="|A-B|"))
-      stop("Chosen test statistic not allowed for this design.")
-    
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
@@ -761,16 +799,26 @@ function(
         distribution[it]<-mean(scores.a[[it]])-mean(scores.b[[it]])
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
+    else if(statistic=="B-A"){
       for(it in 1:number)
         distribution[it]<-mean(scores.b[[it]])-mean(scores.a[[it]])
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
+    else if(statistic=="|A-B|"){
       for(it in 1:number)
         distribution[it]<-abs(mean(scores.a[[it]])-mean(scores.b[[it]]))
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:number){
+        A<-scores.a[[it]]
+        B<-scores.b[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
     
     distribution<-sort(distribution)
     test<-distribution>=observed.statistic
