@@ -20,35 +20,47 @@ function(
       }
       observed<-data[,2]
       scores.a<-combn(observed,MT/2)
-      mean.a<-numeric(ncol(scores.a))
-      for(it in 1:ncol(scores.a)){
-        mean.a[it]<-mean(scores.a[,it])
-      }
-      mean.b<-rev(mean.a)
-      if(statistic=="A-B"){
-        distribution<-numeric(length(mean.a))
-        for(it in 1:length(mean.a)){
-          distribution[it]<-mean.a[it]-mean.b[it]
+      distribution<-numeric(ncol(scores.a))
+      
+      if(statistic %in% c("A-B","B-A","|A-B|")){
+        mean.a<-numeric(ncol(scores.a))
+        for(it in 1:ncol(scores.a)){
+          mean.a[it]<-mean(scores.a[,it])
         }
-        distribution<-sort(distribution)
-        observed.statistic<-mean(observed.a)-mean(observed.b)
-      }
-      if(statistic=="B-A"){
-        distribution<-numeric(length(mean.a))
-        for(it in 1:length(mean.a)){
-          distribution[it]<-mean.b[it]-mean.a[it]
+        mean.b<-rev(mean.a)
+        if(statistic=="A-B"){
+          for(it in 1:length(mean.a)){
+            distribution[it]<-mean.a[it]-mean.b[it]
+          }
+          observed.statistic<-mean(observed.a)-mean(observed.b)
         }
-        distribution<-sort(distribution)
-        observed.statistic<-mean(observed.b)-mean(observed.a)
-      }
-      if(statistic=="|A-B|"){
-        distribution<-numeric(length(mean.a))
-        for(it in 1:length(mean.a)){
-          distribution[it]<-abs(mean.a[it]-mean.b[it])
+        else if(statistic=="B-A"){
+          for(it in 1:length(mean.a)){
+            distribution[it]<-mean.b[it]-mean.a[it]
+          }
+          observed.statistic<-mean(observed.b)-mean(observed.a)
+        }
+        else if(statistic=="|A-B|"){
+          for(it in 1:length(mean.a)){
+            distribution[it]<-abs(mean.a[it]-mean.b[it])
+          }
+          observed.statistic<-abs(mean(observed.a)-mean(observed.b))
         }
-        distribution<-sort(distribution)
-        observed.statistic<-abs(mean(observed.a)-mean(observed.b))
       }
+      else{
+        scores.b<-rev(scores.a)
+        dim(scores.b)<-c(MT/2,ncol(scores.a))
+        for(it in 1:ncol(scores.a)){
+          A<-scores.a[,it]
+          B<-scores.b[,it]
+          distribution[it]<-eval(parse(text=statistic))
+        }
+        A<-observed.a
+        B<-observed.b
+        observed.statistic<-eval(parse(text=statistic))
+      }
+      
+      distribution<-sort(distribution)
       test<-distribution>=observed.statistic
       p.value<-sum(test)/quantity
       if(save=="yes"|save=="check"){
@@ -105,30 +117,38 @@ function(
       }
       scores.a<-as.matrix(scores.a)
       scores.b<-as.matrix(scores.b)
+      distribution<-numeric(quantity)
+      
       if(statistic=="A-B"){
-        distribution<-numeric(quantity)
         for(it in 1:quantity){
           distribution[it]<-mean(scores.a[it,])-mean(scores.b[it,])
         }
-        distribution<-sort(distribution)
         observed.statistic<-mean(observed.a)-mean(observed.b)
       }
-      if(statistic=="B-A"){
-        distribution<-numeric(quantity)
+      else if(statistic=="B-A"){
         for(it in 1:quantity){
           distribution[it]<-mean(scores.b[it,])-mean(scores.a[it,])
         }
-        distribution<-sort(distribution)
         observed.statistic<-mean(observed.b)-mean(observed.a)
       }
-      if(statistic=="|A-B|"){
-        distribution<-numeric(quantity)
+      else if(statistic=="|A-B|"){
         for(it in 1:quantity){
           distribution[it]<-abs(mean(scores.a[it,])-mean(scores.b[it,]))
         }
-        distribution<-sort(distribution)
         observed.statistic<-abs(mean(observed.a)-mean(observed.b))
       }
+      else{
+        for(it in 1:quantity){
+          A<-scores.a[it,]
+          B<-scores.b[it,]
+          distribution[it]<-eval(parse(text=statistic))
+        }
+        A<-observed.a
+        B<-observed.b
+        observed.statistic<-eval(parse(text=statistic))
+      }
+      
+      distribution<-sort(distribution)
       test<-distribution>=observed.statistic
       p.value<-sum(test)/quantity
       unlink(fileCRD,recursive=FALSE)
@@ -159,30 +179,38 @@ function(
     for(it in 1:(MT/2)){
       scores.b<-cbind(scores.b,cbind(rep(cbind(rep(observed2[,it],rep(2^it/2,2))),2^(MT/2)/2^it)))
     }
+    distribution<-numeric(quantity)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(quantity)
       for(it in 1:quantity){
         distribution[it]<-mean(scores.a[it,])-mean(scores.b[it,])
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(quantity)
+    else if(statistic=="B-A"){
       for(it in 1:quantity){
         distribution[it]<-mean(scores.b[it,])-mean(scores.a[it,])
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|A-B|"){
       for(it in 1:quantity){
         distribution[it]<-abs(mean(scores.a[it,])-mean(scores.b[it,]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:quantity){
+        A<-scores.a[it,]
+        B<-scores.b[it,]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/quantity
     if(save=="yes"|save=="check"){
@@ -263,30 +291,38 @@ function(
         scores.b<-cbind(scores.b,data[,2][indexes.b[,it]])
       }
       quantity<-nrow(scores.a)
+      distribution<-numeric(quantity)
+      
       if(statistic=="A-B"){
-        distribution<-numeric(nrow(scores.a))
-        for(it in 1:nrow(scores.a)){
+        for(it in 1:quantity){
           distribution[it]<-mean(scores.a[it,])-mean(scores.b[it,])
         }
-        distribution<-sort(distribution)
         observed.statistic<-mean(observed.a)-mean(observed.b)
       }
-      if(statistic=="B-A"){
-        distribution<-numeric(nrow(scores.a))
-        for(it in 1:nrow(scores.a)){
+      else if(statistic=="B-A"){
+        for(it in 1:quantity){
           distribution[it]<-mean(scores.b[it,])-mean(scores.a[it,])
         }
-        distribution<-sort(distribution)
         observed.statistic<-mean(observed.b)-mean(observed.a)
       }
-      if(statistic=="|A-B|"){
-        distribution<-numeric(nrow(scores.a))
-        for(it in 1:nrow(scores.a)){
+      else if(statistic=="|A-B|"){
+        for(it in 1:quantity){
           distribution[it]<-abs(mean(scores.a[it,])-mean(scores.b[it,]))
         }
-        distribution<-sort(distribution)
         observed.statistic<-abs(mean(observed.a)-mean(observed.b))
       }
+      else{
+        for(it in 1:quantity){
+          A<-scores.a[it,]
+          B<-scores.b[it,]
+          distribution[it]<-eval(parse(text=statistic))
+        }
+        A<-observed.a
+        B<-observed.b
+        observed.statistic<-eval(parse(text=statistic))
+      }
+      
+      distribution<-sort(distribution)
       test<-distribution>=observed.statistic
       p.value<-sum(test)/quantity
       if(save=="yes"|save=="check"){
@@ -370,30 +406,38 @@ function(
       scores.a<-as.matrix(scores.a)
       scores.b<-as.matrix(scores.b)
       quantity<-nrow(scores.a)
+      distribution<-numeric(quantity)
+      
       if(statistic=="A-B"){
-        distribution<-numeric(nrow(scores.a))
-        for(it in 1:nrow(scores.a)){
+        for(it in 1:quantity){
           distribution[it]<-mean(scores.a[it,])-mean(scores.b[it,])
         }
-        distribution<-sort(distribution)
         observed.statistic<-mean(observed.a)-mean(observed.b)
       }
-      if(statistic=="B-A"){
-        distribution<-numeric(nrow(scores.a))
-        for(it in 1:nrow(scores.a)){
+      else if(statistic=="B-A"){
+        for(it in 1:quantity){
           distribution[it]<-mean(scores.b[it,])-mean(scores.a[it,])
         }
-        distribution<-sort(distribution)
         observed.statistic<-mean(observed.b)-mean(observed.a)
       }
-      if(statistic=="|A-B|"){
-        distribution<-numeric(nrow(scores.a))
-        for(it in 1:nrow(scores.a)){
+      else if(statistic=="|A-B|"){
+        for(it in 1:quantity){
           distribution[it]<-abs(mean(scores.a[it,])-mean(scores.b[it,]))
         }
-        distribution<-sort(distribution)
         observed.statistic<-abs(mean(observed.a)-mean(observed.b))
       }
+      else{
+        for(it in 1:quantity){
+          A<-scores.a[it,]
+          B<-scores.b[it,]
+          distribution[it]<-eval(parse(text=statistic))
+        }
+        A<-observed.a
+        B<-observed.b
+        observed.statistic<-eval(parse(text=statistic))
+      }
+      
+      distribution<-sort(distribution)
       test<-distribution>=observed.statistic
       p.value<-sum(test)/quantity
       unlink(fileCRD,recursive=FALSE)
@@ -424,39 +468,44 @@ function(
     for(it in 1:quantity){
       scores.b[[it]]<-c(observed[(index.a[it]+1):MT])
     }
+    distribution<-numeric(quantity)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(quantity)
       for(it in 1:quantity){
         distribution[it]<-mean(scores.a[[it]])-mean(scores.b[[it]])
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(quantity)
+    else if(statistic=="B-A"){
       for(it in 1:quantity){
         distribution[it]<-mean(scores.b[[it]])-mean(scores.a[[it]])
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|A-B|"){
       for(it in 1:quantity){
         distribution[it]<-abs(mean(scores.a[[it]])-mean(scores.b[[it]]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:quantity){
+        A<-scores.a[[it]]
+        B<-scores.b[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/quantity
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-    }
-    if(save=="no"){
-      return(p.value)
     }
+    return(p.value)
   }
   
   if(design=="ABA"){
@@ -518,87 +567,86 @@ function(
     for(it in 1:quantity){
       mean.a2[it]<-mean(scores.a2[[it]])
     }
+    distribution<-numeric(quantity)
+    
     if(statistic=="A-B"){	
-      distribution<-numeric(quantity)
       for(it in 1:quantity){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b1)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(quantity)
+    else if(statistic=="B-A"){
       for(it in 1:quantity){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b1)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|A-B|"){
       for(it in 1:quantity){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b1))
     }
-    if(statistic=="PA-PB"){
-      distribution<-numeric(quantity)
+    else if(statistic=="PA-PB"){
       for(it in 1:quantity){
         distribution[it]<-pmean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-((mean(observed.a1)+mean(observed.a2))/2)-mean(observed.b1)
     }
-    if(statistic=="PB-PA"){
-      distribution<-numeric(quantity)
+    else if(statistic=="PB-PA"){
       for(it in 1:quantity){
         distribution[it]<-mean.b[it]-pmean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b1)-((mean(observed.a1)+mean(observed.a2))/2)
     }
-    if(statistic=="|PA-PB|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|PA-PB|"){
       for(it in 1:quantity){
         distribution[it]<-abs(pmean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(((mean(observed.a1)+mean(observed.a2))/2)-mean(observed.b1))
     }
-    if(statistic=="AA-BB"){
-      distribution<-numeric(quantity)
+    else if(statistic=="AA-BB"){
       for(it in 1:quantity){
         distribution[it]<-(mean.a1[it]+mean.a2[it])-(mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.a1)+mean(observed.a2))-(mean(observed.b1))
     }
-    if(statistic=="BB-AA"){
-      distribution<-numeric(quantity)
+    else if(statistic=="BB-AA"){
       for(it in 1:quantity){
         distribution[it]<-mean.b[it]-(mean.a1[it]+mean.a2[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.b1))-(mean(observed.a1)+mean(observed.a2))
     }
-    if(statistic=="|AA-BB|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|AA-BB|"){
       for(it in 1:quantity){
         distribution[it]<-abs((mean.a1[it]+mean.a2[it])-(mean.b[it]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs((mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)))
     }
+    else{
+      for(it in 1:quantity){
+        A1<-scores.a1[[it]]
+        B1<-scores.b1[[it]]
+        A2<-scores.a2[[it]]
+        A<-scores.a[[it]]
+        B<-scores.b1[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A1<-observed.a1
+      B1<-observed.b1	
+      A2<-observed.a2
+      A<-observed.a
+      B<-observed.b1
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/quantity
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-    }
-    if(save=="no"){
-      return(p.value)
     }
+    return(p.value)
   }
   
   if(design=="ABAB"){
@@ -690,87 +738,88 @@ function(
     for(it in 1:quantity){
       mean.b2[it]<-mean(scores.b2[[it]])
     }
+    distribution<-numeric(quantity)
+    
     if(statistic=="A-B"){
-      distribution<-numeric(quantity)
       for(it in 1:quantity){
         distribution[it]<-mean.a[it]-mean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
-      distribution<-numeric(quantity)
+    else if(statistic=="B-A"){
       for(it in 1:quantity){
         distribution[it]<-mean.b[it]-mean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|A-B|"){
       for(it in 1:quantity){
         distribution[it]<-abs(mean.a[it]-mean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
-    if(statistic=="PA-PB"){
-      distribution<-numeric(quantity)
+    else if(statistic=="PA-PB"){
       for(it in 1:quantity){
         distribution[it]<-pmean.a[it]-pmean.b[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-((mean(observed.a1)+mean(observed.a2))/2)-((mean(observed.b1)+mean(observed.b2))/2)
     }
-    if(statistic=="PB-PA"){
-      distribution<-numeric(quantity)
+    else if(statistic=="PB-PA"){
       for(it in 1:quantity){
         distribution[it]<-pmean.b[it]-pmean.a[it]
       }
-      distribution<-sort(distribution)
       observed.statistic<-((mean(observed.b1)+mean(observed.b2))/2)-((mean(observed.a1)+mean(observed.a2))/2)
     }
-    if(statistic=="|PA-PB|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|PA-PB|"){
       for(it in 1:quantity){
         distribution[it]<-abs(pmean.a[it]-pmean.b[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs(((mean(observed.a1)+mean(observed.a2))/2)-((mean(observed.b1)+mean(observed.b2))/2))
     }
-    if(statistic=="AA-BB"){
-      distribution<-numeric(quantity)
+    else if(statistic=="AA-BB"){
       for(it in 1:quantity){
         distribution[it]<-(mean.a1[it]+mean.a2[it])-(mean.b1[it]+mean.b2[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)+mean(observed.b2))
     }
-    if(statistic=="BB-AA"){
-      distribution<-numeric(quantity)
+    else if(statistic=="BB-AA"){
       for(it in 1:quantity){
         distribution[it]<-(mean.b1[it]+mean.b2[it])-(mean.a1[it]+mean.a2[it])
       }
-      distribution<-sort(distribution)
       observed.statistic<-(mean(observed.b1)+mean(observed.b2))-(mean(observed.a1)+mean(observed.a2))
     }
-    if(statistic=="|AA-BB|"){
-      distribution<-numeric(quantity)
+    else if(statistic=="|AA-BB|"){
       for(it in 1:quantity){
         distribution[it]<-abs((mean.a1[it]+mean.a2[it])-(mean.b1[it]+mean.b2[it]))
       }
-      distribution<-sort(distribution)
       observed.statistic<-abs((mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)+mean(observed.b2)))
     }
+    else{
+      for(it in 1:quantity){
+        A1<-scores.a1[[it]]
+        B1<-scores.b1[[it]]
+        A2<-scores.a2[[it]]
+        B2<-scores.b2[[it]]
+        A<-scores.a[[it]]
+        B<-scores.b[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A1<-observed.a1
+      B1<-observed.b1	
+      A2<-observed.a2
+      B2<-observed.b2
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
+    
+    distribution<-sort(distribution)
     test<-distribution>=observed.statistic
     p.value<-sum(test)/quantity
     if(save=="yes"|save=="check"){
       write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-    }
-    if(save=="no"){
-      return(p.value)
     }
+    return(p.value)
   }
   
   if(design=="MBD"){
@@ -896,24 +945,31 @@ function(
     for(it in 1:N){
       observed.b[[it]]<-data[,it*2][data[,(it*2)-1]=="B"]
     }
+    differences<-numeric(N)
+    
     if(statistic=="A-B"){
-      differences<-numeric(N)
       for(it in 1:N){
         differences[it]<-mean(observed.a[[it]])-mean(observed.b[[it]])
       }
     }
-    if(statistic=="B-A"){
-      differences<-numeric(N)
+    else if(statistic=="B-A"){
       for(it in 1:N){
         differences[it]<-mean(observed.b[[it]])-mean(observed.a[[it]])
       }
     }
-    if(statistic=="|A-B|"){
-      differences<-numeric(N)
+    else if(statistic=="|A-B|"){
       for(it in 1:N){
         differences[it]<-abs(mean(observed.b[[it]])-mean(observed.a[[it]]))
       }
     }
+    else{
+      for(it in 1:N){
+        A<-observed.a[[it]]
+        B<-observed.b[[it]]
+        differences[it]<-eval(parse(text=statistic))
+      }
+    }
+    
     observed.statistic<-mean(differences)
     scores.a<-list()
     for(iter in 1:nrow(assignments)){
@@ -931,8 +987,9 @@ function(
       }
       scores.b[[iter]]<-bscores
     }
+    differs<-list()
+    
     if(statistic=="A-B"){
-      differs<-list()
       for(iter in 1:nrow(assignments)){
         differ<-numeric(N)
         for(it in 1:N){
@@ -941,8 +998,7 @@ function(
         differs[[iter]]<-differ
       }
     }
-    if(statistic=="B-A"){
-      differs<-list()
+    else if(statistic=="B-A"){
       for(iter in 1:nrow(assignments)){
         differ<-numeric(N)
         for(it in 1:N){
@@ -951,8 +1007,7 @@ function(
         differs[[iter]]<-differ
       }
     }
-    if(statistic=="|A-B|"){
-      differs<-list()
+    else if(statistic=="|A-B|"){
       for(iter in 1:nrow(assignments)){
         differ<-numeric(N)
         for(it in 1:N){
@@ -961,6 +1016,18 @@ function(
         differs[[iter]]<-differ
       }
     }
+    else{
+      for(iter in 1:nrow(assignments)){
+        differ<-numeric(N)
+        for(it in 1:N){
+          A<-scores.a[[iter]][[it]]
+          B<-scores.b[[iter]][[it]]
+          differ[it]<-eval(parse(text=statistic))
+        }
+        differs[[iter]]<-differ
+      }
+    }
+    
     distribution<-numeric(nrow(assignments))
     for(it in 1:nrow(assignments)){
       distribution[it]<-mean(differs[[it]])
@@ -973,23 +1040,14 @@ function(
     }
     if(save=="yes"|save=="check"){
       write.table(distribution,file=fileSAVE,col.names=FALSE,row.names=FALSE,append=FALSE)
-      return(p.value)
-      unlink(fileSTARTPTS,recursive=FALSE)
-      unlink(fileCOMBSTARTPOINTS,recursive=FALSE)
-      unlink(fileASSIGNMENTS,recursive=FALSE)
-    }
-    if(save=="no"){
-      return(p.value)
-      unlink(fileSTARTPTS,recursive=FALSE)
-      unlink(fileCOMBSTARTPOINTS,recursive=FALSE)
-      unlink(fileASSIGNMENTS,recursive=FALSE)
     }
+    unlink(fileSTARTPTS,recursive=FALSE)
+    unlink(fileCOMBSTARTPOINTS,recursive=FALSE)
+    unlink(fileASSIGNMENTS,recursive=FALSE)
+    return(p.value)
   }
   
   if(design=="Custom"){
-    if(!(statistic=="A-B"||statistic=="B-A"||statistic=="|A-B|"))
-      stop("Chosen test statistic not allowed for this design.")
-    
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
@@ -1014,16 +1072,26 @@ function(
         distribution[it]<-mean(scores.a[[it]])-mean(scores.b[[it]])
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
+    else if(statistic=="B-A"){
       for(it in 1:quantity)
         distribution[it]<-mean(scores.b[[it]])-mean(scores.a[[it]])
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
+    else if(statistic=="|A-B|"){
       for(it in 1:quantity)
         distribution[it]<-abs(mean(scores.a[[it]])-mean(scores.b[[it]]))
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      for(it in 1:quantity){
+        A<-scores.a[[it]]
+        B<-scores.b[[it]]
+        distribution[it]<-eval(parse(text=statistic))
+      }
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
     
     distribution<-sort(distribution)
     test<-distribution>=observed.statistic
